<?php

namespace TVn7\ForumBundle\DependencyInjection;

use Symfony\Component\Config\Definition\Builder\TreeBuilder;
use Symfony\Component\Config\Definition\ConfigurationInterface;

/**
 * This is the class that validates and merges configuration from your app/config files
 *
 * To learn more see {@link http://symfony.com/doc/current/cookbook/bundles/extension.html#cookbook-bundles-extension-config-class}
 */
class Configuration implements ConfigurationInterface
{

    /**
     * {@inheritDoc}
     */
    public function getConfigTreeBuilder()
    {
        $treeBuilder = new TreeBuilder();
        $rootNode = $treeBuilder->root('t_vn7_forum')
                ->children()
                    ->integerNode("max_topics_per_page")
                        ->isRequired()
                        ->defaultValue(10)
                        ->min(1)
                    ->end()
                    ->integerNode("max_comments_per_page")
                        ->isRequired()
                        ->defaultValue(10)
                        ->min(1)
                    ->end()
                    ->arrayNode("emojis")
                        ->isRequired()
                        ->scalarPrototype()->end()
                    ->end()
                    ->integerNode("max_page_in_selector")
                        ->isRequired()
                        ->defaultValue(5)
                        ->min(5)
                        ->validate()
                        ->ifTrue(function ($nb) { return !($nb%2); })
                            ->thenInvalid("max_page_in_selector must be odd. %s given.")
                        ->end()
                    ->end()
                ->end();


        // Here you should define the parameters that are allowed to
        // configure your bundle. See the documentation linked above for
        // more information on that topic.

        return $treeBuilder;
    }
}
